@@ -3,7 +3,8 @@
 Created on:    Apr 1, 2014
 @author:        vahid
 '''
-from pymlconf import ConfigManager,ConfigList
+from pymlconf import ConfigManager, ConfigList, ConfigDict
+
 import os.path
 
 
@@ -21,8 +22,12 @@ class Manifest(ConfigManager):
             else:
                 manifest_config.libdirs = ConfigList()
 
-            if not manifest_config.output.startswith('/'):
-                manifest_config.output = os.path.abspath(os.path.join(manifest_dir, manifest_config.output))
+            if isinstance(manifest_config.output, basestring):
+                manifest_config.output = ConfigDict({'normal': manifest_config.output})
+
+            for k, v in manifest_config.output.items():
+                if not v.startswith('/'):
+                    manifest_config.output[k] = os.path.abspath(os.path.join(manifest_dir, v))
 
     def get_task_names(self):
         for k in self.keys():
