@@ -5,7 +5,7 @@ Created on:    Nov 10, 2013
 '''
 from watchdog.events import FileSystemEventHandler
 from watchdog.observers import Observer
-from isass.helpers import get_source_dirs,get_source_files,distinct,split_paths
+from isass.helpers import get_source_dirs, get_source_files, distinct, split_paths, minify
 from isass import SassCompiler
 import os.path
 from isass.manifest import Manifest
@@ -16,8 +16,8 @@ import traceback
 class IsassEventHandler(FileSystemEventHandler):
     extension = '.sass'
 
-    def __init__(self, outfile, dirs, files=None, lib_dirs = None):
-        self.outfile = outfile
+    def __init__(self, outfiles, dirs, files=None, lib_dirs = None):
+        self.outfiles = outfiles
         self.dirs = dirs
         self.lib_dirs = lib_dirs if lib_dirs else []
         self.source_files = get_source_files(self.dirs,extension=self.extension)
@@ -37,9 +37,20 @@ class IsassEventHandler(FileSystemEventHandler):
                 print "Reading %s" % os.path.abspath(sf)
                 compiler.read_file(sf)
 
-            print "Writing %s" % os.path.abspath(self.outfile)
-            with open(self.outfile, 'w') as of:
-                of.write(compiler.get_css())
+
+            normal_output = compiler.get_css()
+            if 'normal' in self.outfiles:
+                normal_out_filename = os.path.abspath(self.outfiles['normal'])
+                print "Writing %s" % normal_out_filename
+                with open(normal_out_filename, 'w') as of:
+                    of.write(normal_output)
+
+            if 'minified' in self.outfiles:
+                minified_out_filename = os.path.abspath(self.outfiles['minified'])
+                print "Writing %s" % minified_out_filename
+                with open(minified_out_filename, 'w') as of:
+                    of.write(minify(normal_output))
+
         except:
             exc_type, exc_value, exc_traceback = sys.exc_info()
             traceback.print_exception(exc_type, exc_value, exc_traceback)
@@ -68,7 +79,11 @@ class IsassEventHandler(FileSystemEventHandler):
 
 class SassObserver(Observer):
 
-    def add_output(self, outfile, dirs=None, files=None, lib_dirs=None):
+    def add_output(self, outfiles, dirs=None, files=None, lib_dirs=None):
+
+        if isinstance(outfiles, basestring):
+            outfiles = {'normal': outfiles}
+
         if dirs is None:
             dirs = []
 
@@ -80,7 +95,7 @@ class SassObserver(Observer):
 
         dirs = distinct(split_paths(dirs))
 
-        handler = IsassEventHandler(outfile, dirs, files=files, lib_dirs=lib_dirs)
+        handler = IsassEventHandler(outfiles, dirs, files=files, lib_dirs=lib_dirs)
         watch_dirs = list(dirs)
 
         if lib_dirs:
@@ -105,4 +120,7 @@ class SassObserver(Observer):
                     files.append(s)
                 else:
                     dirs.append(s)
-            self.add_output(outfile=task.output, dirs=dirs, files = files, lib_dirs=task.libdirs)
+            self.add_output(outfiles=task.output,
+                            dirs=dirs,
+                            files=files,
+                            lib_dirs=task.libdirs)
